"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var sharedService_1 = require("../../../models/sharedService");
var core_2 = require("@ngx-translate/core");
var req_http_service_1 = require("../../../services/req-http.service");
var series_component_1 = require("../series/series.component");
var LineComponent = (function () {
    function LineComponent(_el, _sharedService, _translateService, reqHttp) {
        this._el = _el;
        this._sharedService = _sharedService;
        this._translateService = _translateService;
        this.reqHttp = reqHttp;
        this.dataSource = [];
        this.argumentField = 'arg';
        this.width = '100%';
        this.height = 400;
        this.export = true;
        this.texts = true;
        this.indexData = 'data';
        this.onClick = '';
        this.onLegentClick = '';
        this._onClick = new core_1.EventEmitter();
        this._onLegentClick = new core_1.EventEmitter();
        this._legendsOrientation = 'vertical';
        this._type = 'pie';
        this._label = '';
        this._columns = 'col l12 m12 s12';
        sbmGraphLineComponent.push(this);
    }
    Object.defineProperty(LineComponent.prototype, "legendsOrientation", {
        get: function () {
            return this._legendsOrientation;
        },
        set: function (val) {
            if (val == 'horizontal' || val == 'vertical') {
                this._legendsOrientation = val;
            }
            else {
                this._legendsOrientation = 'vertical';
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineComponent.prototype, "type", {
        get: function () {
            return this._type;
        },
        set: function (val) {
            if (val == 'pie' || val == 'donut') {
                this._type = val;
            }
            else {
                this._type = 'pie';
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineComponent.prototype, "label", {
        get: function () {
            return this.privateLabel;
        },
        set: function (val) {
            this.privateLabel = val;
            if (val.substring(0, 1) == '#') {
                this._label = this._translateService.translations[this._translateService.currentLang].i18n['sabium-framework'][val.replace('#', '')];
            }
            else if (val.substring(0, 4) == 'i18n') {
                if (_projectName) {
                    this._label = this._translateService.translations[this._translateService.currentLang].i18n[_projectName][val.replace("i18n.", "")];
                }
                else {
                    this._label = val;
                }
            }
            else {
                this._label = val;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineComponent.prototype, "columns", {
        get: function () {
            return this._columns;
        },
        set: function (value) {
            this._columns = "col l" + value + " m12 s12";
        },
        enumerable: true,
        configurable: true
    });
    LineComponent.prototype.reqService = function (url) {
        var _this = this;
        if (url != '') {
            this.reqHttp.xhrGet(url).subscribe(function (ret) {
                if (typeof ret.res[_this.indexData] == 'object') {
                    if (ret.res[_this.indexData].length > 0) {
                        _this.dataSource = ret.res[_this.indexData];
                    }
                }
            });
        }
    };
    LineComponent.prototype.pointClickHandler = function ($event) {
        this._onClick.emit($event);
        if ($event.target._visible) {
            $event.target.hide();
        }
        else {
            $event.target.show();
        }
        if (this.onClick != '') {
            window[this.onClick]($event);
        }
    };
    LineComponent.prototype.legendClickHandler = function ($event) {
        this._onLegentClick.emit($event);
        var arg = $event.target, item = $event.component.getSeriesByName(arg.name);
        if (item._visible) {
            item.hide();
        }
        else {
            item.show();
        }
        console.log(item._visible);
        this.chartLine.instance.render();
        if (this.onLegentClick != '') {
            window[this.onLegentClick]($event);
        }
    };
    LineComponent.prototype.customizeLabel = function (arg) {
        return arg.valueText;
    };
    LineComponent.prototype.ngOnInit = function () {
    };
    return LineComponent;
}());
LineComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'sbm-chart-line',
                template: "\n    <dx-chart\n        #chartLine\n        [title]=\"_label\"\n        [dataSource]=\"dataSource\"\n        (onSeriesClick)=\"pointClickHandler($event)\"\n        [resolveLabelOverlapping]=\"'shift'\"\n        (onLegendClick)=\"legendClickHandler($event)\">\n        <dxo-legend\n                [orientation]=\"legendsOrientation\"\n                itemTextPosition=\"right\"\n                horizontalAlignment=\"right\"\n                verticalAlignment=\"bottom\">\n        </dxo-legend>\n        <dxi-series *ngFor=\"let item of series\" [valueField]=\"item.valueField\" [name]=\"item.name\" [visible]=\"true\"></dxi-series>\n      \n        <dxo-common-series-settings\n            [argumentField]=\"argumentField\"\n            type=\"line\"\n            hoverMode=\"allArgumentPoints\"\n            selectionMode=\"allArgumentPoints\">\n            <dxo-label [visible]=\"true\"\n            [customizeText]=\"customizeLabel\"\n            [format]=\"{\n                    type: 'fixedPoint',\n                    precision: '0'\n            }\">\n                <dxo-connector\n                    [visible]=\"texts\"\n                    [width]=\"1\"></dxo-connector>\n            </dxo-label>\n        </dxo-common-series-settings>\n        <dxo-size width=\"100%\" [height]=\"height\"></dxo-size>\n        <dxo-export [enabled]=\"export\"></dxo-export>\n    </dx-chart>\n  ",
                host: {
                    '[class]': 'columns'
                }
            },] },
];
/** @nocollapse */
LineComponent.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
    { type: sharedService_1.SharedService, },
    { type: core_2.TranslateService, },
    { type: req_http_service_1.ReqHttpService, },
]; };
LineComponent.propDecorators = {
    'series': [{ type: core_1.ContentChildren, args: [core_1.forwardRef(function () { return series_component_1.SeriesComponent; }),] },],
    'chartLine': [{ type: core_1.ViewChild, args: ['chartLine',] },],
    'dataSource': [{ type: core_1.Input },],
    'argumentField': [{ type: core_1.Input },],
    'width': [{ type: core_1.Input },],
    'height': [{ type: core_1.Input },],
    'export': [{ type: core_1.Input },],
    'texts': [{ type: core_1.Input },],
    'indexData': [{ type: core_1.Input },],
    'onClick': [{ type: core_1.Input },],
    'onLegentClick': [{ type: core_1.Input },],
    '_onClick': [{ type: core_1.Output },],
    '_onLegentClick': [{ type: core_1.Output },],
    'legendsOrientation': [{ type: core_1.Input },],
    'type': [{ type: core_1.Input },],
    'label': [{ type: core_1.Input },],
    'columns': [{ type: core_1.Input },],
};
exports.LineComponent = LineComponent;
