"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var tab_component_1 = require("./tab.component");
var TabsComponent = (function () {
    function TabsComponent(elRef) {
        this.elRef = elRef;
        this.css = 'sbm-tabs';
        this.layout = 'line';
        this.onTabClick = new core_1.EventEmitter();
        this._columns = 'col l12 s12 m12';
        sbmTabsComponent.push(this);
    }
    Object.defineProperty(TabsComponent.prototype, "columns", {
        get: function () {
            return this._columns;
        },
        set: function (value) {
            this._columns = "col l" + value + " s12 m12";
        },
        enumerable: true,
        configurable: true
    });
    TabsComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        $(document).ready(function () {
            if (_this.layout == 'line') {
                $(_this.elRef.nativeElement).find('ul.tabs').tabs({
                    'swipeable': false,
                    'responsiveThreshold': $(_this.ul.nativeElement).outerWidth()
                });
            }
            var activeTabs = _this.tabs.filter(function (tab) { return tab.active; });
            if (activeTabs.length === 0) {
                _this.selectTab(_this.tabs.first);
            }
        });
    };
    TabsComponent.prototype.selectTab = function (tab) {
        if (tab) {
            if (this.layout == 'line') {
                $(this.elRef.nativeElement).find('ul.tabs').tabs('select_tab', tab.randomId);
            }
            this.tabs.toArray().forEach(function (tab) { return tab.active = false; });
            tab.active = true;
            this.onTabClick.emit(tab);
        }
    };
    return TabsComponent;
}());
TabsComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'sbm-tabs',
                template: "\n        <div *ngIf=\"layout == 'line'\">\n            <ul #ul class=\"tabs sbm-tabs-line-layout {{css}}\">\n                <li *ngFor=\"let tab of tabs\" (click)=\"selectTab(!tab.disabled ? tab : null)\" [class.active]=\"tab.active\" [class.disabled]=\"tab.disabled\" class='tab sbm-tab-border-items'>\n                    <a href=\"#{{tab.randomId}}\" [class.active]=\"tab.active\">{{tab._text}}</a>\n                </li>\n            </ul>\n        </div>\n        \n        <div *ngIf=\"layout == 'window'\" class=\"sbm-tab-container\">\n            <ul class=\"sbm-tabs-content clearfix chrome-tabs\">\n              <li class=\"sbm-tab-items\" *ngFor=\"let tab of tabs\" (click)=\"selectTab(!tab.disabled ? tab : null)\" [class.active]=\"tab.active\" [class.disabled]=\"tab.disabled\">\n                <a>{{tab.text}}</a>\n              </li>\n            </ul>\n        </div>\n        \n        <div #tabsContent class=\"row\" style=\"border: 1px solid #ddd;\">\n            <ng-content></ng-content>\n        </div>\n    ",
                styles: ["\n        ul.tabs li.disabled a {\n            pointer-events: none;\n            opacity: 0.4;\n        }\n\n        ul.tabs::-webkit-scrollbar {\n            height: 8px;\n        }\n\n        ul.tabs::-webkit-scrollbar-thumb {\n            background: #6d6d6d;\n        }\n    "],
                host: {
                    '[class]': 'columns'
                }
            },] },
];
/** @nocollapse */
TabsComponent.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
]; };
TabsComponent.propDecorators = {
    'el': [{ type: core_1.ViewChild, args: ['tabs',] },],
    'tabsContent': [{ type: core_1.ViewChild, args: ['tabsContent', { read: core_1.ViewContainerRef },] },],
    'ul': [{ type: core_1.ViewChild, args: ['ul',] },],
    'css': [{ type: core_1.Input },],
    'layout': [{ type: core_1.Input },],
    'onTabClick': [{ type: core_1.Output },],
    'columns': [{ type: core_1.Input },],
    'tabs': [{ type: core_1.ContentChildren, args: [tab_component_1.TabComponent,] },],
};
exports.TabsComponent = TabsComponent;
